Struct rkyv::rel_ptr::RelPtr [−][src]
pub struct RelPtr<T: ArchivePointee + ?Sized, O> { /* fields omitted */ }Expand description
Implementations
Attempts to create a relative pointer from one position to another.
Safety
frommust be the position ofoutwithin the archivetomust be the position of some validT
Attempts to create a null relative pointer with default metadata.
Safety
pos must be the position of out within the archive.
pub unsafe fn try_resolve_emplace<U: ArchiveUnsized<Archived = T> + ?Sized>(
from: usize,
to: usize,
value: &U,
metadata_resolver: U::MetadataResolver,
out: *mut Self
) -> Result<(), OffsetError>
pub unsafe fn try_resolve_emplace<U: ArchiveUnsized<Archived = T> + ?Sized>(
from: usize,
to: usize,
value: &U,
metadata_resolver: U::MetadataResolver,
out: *mut Self
) -> Result<(), OffsetError>
Attempts to create a relative pointer from one position to another.
Safety
frommust be the position ofoutwithin the archivetomust be the position of some validTvaluemust be the value being serializedmetadata_resolvermust be the result of serializing the metadata ofvalue
pub unsafe fn resolve_emplace<U: ArchiveUnsized<Archived = T> + ?Sized>(
from: usize,
to: usize,
value: &U,
metadata_resolver: U::MetadataResolver,
out: *mut Self
)
pub unsafe fn resolve_emplace<U: ArchiveUnsized<Archived = T> + ?Sized>(
from: usize,
to: usize,
value: &U,
metadata_resolver: U::MetadataResolver,
out: *mut Self
)
Creates a relative pointer from one position to another.
Panics
- The offset between
fromandtodoes not fit in anisize - The offset between
fromandtoexceeds the offset storage
Safety
frommust be the position ofoutwithin the archivetomust be the position of some validTvaluemust be the value being serializedmetadata_resolvermust be the result of serializing the metadata ofvalue
Gets the metadata of the relative pointer.
Calculates the memory address being pointed to by this relative pointer.
Returns an unsafe mutable pointer to the memory address being pointed to by this relative pointer.